python-bchlib
=============

This is a python module for encoding, decoding, and correcting data using [BCH codes](https://en.wikipedia.org/wiki/BCH_code).

## Requirements
  Python 3.6 or greater required.

## Installing the latest release:
    $ pip install bchlib

## Installing from source:
  Make sure you have python-dev setup.  For Windows, this means you need [Visual Studio 2015](https://stackoverflow.com/a/44290942/6844002).

    $ pip install .

## Usage Example

  See [the tests directory](tests) for usage examles.
